summaryrefslogtreecommitdiff
path: root/lib/sqlalchemy/dialects/postgresql/json.py
diff options
context:
space:
mode:
authorVille Skyttä <ville.skytta@iki.fi>2016-10-07 13:18:58 +0300
committerVille Skyttä <ville.skytta@iki.fi>2016-10-08 20:42:50 +0300
commit8c2c464cb8e1b40f90f544295afbf9a83b372eb7 (patch)
tree09a6c0d0f76f77c8de444fd60e0049a203de7966 /lib/sqlalchemy/dialects/postgresql/json.py
parente47063bfe0de1318c12a4f9ef67b9538cad34489 (diff)
downloadsqlalchemy-8c2c464cb8e1b40f90f544295afbf9a83b372eb7.tar.gz
spelling: Postgresql -> PostgreSQL
Diffstat (limited to 'lib/sqlalchemy/dialects/postgresql/json.py')
-rw-r--r--lib/sqlalchemy/dialects/postgresql/json.py8
1 files changed, 4 insertions, 4 deletions
diff --git a/lib/sqlalchemy/dialects/postgresql/json.py b/lib/sqlalchemy/dialects/postgresql/json.py
index 821018471..8d09b46be 100644
--- a/lib/sqlalchemy/dialects/postgresql/json.py
+++ b/lib/sqlalchemy/dialects/postgresql/json.py
@@ -87,16 +87,16 @@ colspecs[sqltypes.JSON.JSONPathType] = JSONPathType
class JSON(sqltypes.JSON):
"""Represent the Postgresql JSON type.
This type is a specialization of the Core-level :class:`.types.JSON`
type. Be sure to read the documentation for :class:`.types.JSON` for
important tips regarding treatment of NULL values and ORM use.
- .. versionchanged:: 1.1 :class:`.postgresql.JSON` is now a Postgresql-
+ .. versionchanged:: 1.1 :class:`.postgresql.JSON` is now a PostgreSQL-
specific specialization of the new :class:`.types.JSON` type.
- The operators provided by the Postgresql version of :class:`.JSON`
+ The operators provided by the PostgreSQL version of :class:`.JSON`
include:
* Index operations (the ``->`` operator)::
@@ -219,7 +219,7 @@ ischema_names['json'] = JSON
class JSONB(JSON):
"""Represent the Postgresql JSONB type.
The :class:`.JSONB` type stores arbitrary JSONB format data, e.g.::
@@ -87,16 +87,16 @@ colspecs[sqltypes.JSON.JSONPathType] = JSONPathType
class JSON(sqltypes.JSON):
- """Represent the Postgresql JSON type.
+ """Represent the PostgreSQL JSON type.
This type is a specialization of the Core-level :class:`.types.JSON`
type. Be sure to read the documentation for :class:`.types.JSON` for
@@ -219,7 +219,7 @@ ischema_names['json'] = JSON
class JSONB(JSON):
- """Represent the Postgresql JSONB type.
+ """Represent the PostgreSQL JSONB type.
The :class:`.JSONB` type stores arbitrary JSONB format data, e.g.::